src/eric7/EricXML/XMLStreamReaderBase.py

branch
eric7
changeset 10423
299802979277
parent 9653
e67609152c5e
child 10439
21c28b0f9e41
--- a/src/eric7/EricXML/XMLStreamReaderBase.py	Tue Dec 19 11:04:03 2023 +0100
+++ b/src/eric7/EricXML/XMLStreamReaderBase.py	Tue Dec 19 19:57:08 2023 +0100
@@ -24,7 +24,8 @@
         """
         Constructor
 
-        @param device reference to the I/O device to read from (QIODevice)
+        @param device reference to the I/O device to read from
+        @type QIODevice
         """
         super().__init__(device)
 
@@ -33,7 +34,9 @@
         Public method to convert the given value to bool.
 
         @param value value to be converted ("True", "False", "1", "0")
-        @return converted value (boolean) or None in case of an error
+        @type str
+        @return converted value or None in case of an error
+        @rtype bool
         """
         if value.lower() in ["true", "false"]:
             return value.lower() == "true"
@@ -75,7 +78,8 @@
         """
         Public method to raise an error for an unexpected start tag.
 
-        @param tag name of the unexpected tag (string)
+        @param tag name of the unexpected tag
+        @type str
         """
         self.raiseError(
             QCoreApplication.translate(
@@ -87,7 +91,8 @@
         """
         Public method to raise an error for an unsupported file format version.
 
-        @param version unsupported version (string)
+        @param version unsupported version
+        @type str
         """
         self.raiseError(
             QCoreApplication.translate(
@@ -99,7 +104,8 @@
         """
         Public method to raise an error for a bad value.
 
-        @param value bad value (string)
+        @param value bad value
+        @type str
         """
         self.raiseError(
             QCoreApplication.translate("XMLStreamReaderBase", "Bad value: {0}").format(
@@ -117,9 +123,12 @@
         """
         Public method to read the given attribute of the current tag.
 
-        @param name name of the attribute (string)
-        @param default default value (string)
-        @return value of the requested tag attribute (string)
+        @param name name of the attribute
+        @type str
+        @param default default value
+        @type str
+        @return value of the requested tag attribute
+        @rtype str
         """
         try:
             att = self.attributes().value(name)
@@ -159,6 +168,7 @@
         Protected method to read an object of a basic Python type.
 
         @return Python object read
+        @rtype Any
         """
         while not self.atEnd():
             self.readNext()
@@ -234,6 +244,7 @@
         Private method to read a Python tuple.
 
         @return Python tuple
+        @rtype tuple
         """
         li = []
         while not self.atEnd():
@@ -248,6 +259,7 @@
         Private method to read a Python list.
 
         @return Python list
+        @rtype list
         """
         li = []
         while not self.atEnd():
@@ -262,6 +274,7 @@
         Private method to read a Python dictionary.
 
         @return Python dictionary
+        @rtype dict
         """
         d = {}
         while not self.atEnd():
@@ -282,6 +295,7 @@
         Private method to read a Python set.
 
         @return Python set
+        @rtype set
         """
         li = []
         while not self.atEnd():
@@ -293,9 +307,10 @@
 
     def __readFrozenset(self):
         """
         Private method to read a Python set.
 
-        @return Python set
+        @return Python frozenset
+        @rtype frozenset
         """
         li = []
         while not self.atEnd():
@@ -293,9 +307,10 @@
     def __readFrozenset(self):
         """
-        Private method to read a Python set.
+        Private method to read a Python frozenset.
 

eric ide

mercurial